@@ -171,7 +171,7 @@ namespace Breeze
         void renderSidePanelFrame( QPainter*, const QRect&, const QColor& outline, Side ) const;
 
         //* menu frame
-        void renderMenuFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline, bool roundCorners = true ) const;
+        void renderMenuFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline, bool roundCorners = true, bool isTopMenu = false ) const;
 
         //* button frame
         void renderButtonFrame( QPainter*, const QRect&, const QColor& color, const QColor& outline, const QColor& shadow, bool focus, bool sunken ) const;
@@ -240,7 +240,10 @@ namespace Breeze
         void renderScrollBarBorder( QPainter*, const QRect&, const QColor& ) const;
 
         //* tabbar tab
-        void renderTabBarTab( QPainter*, const QRect&, const QColor& color, const QColor& outline, Corners ) const;
+        void renderTabBarTab( QPainter*, const QRect&, const QColor& color, const QColor& highlight, const QColor& outline, Corners, bool document, bool bottom ) const;
+        // TODO(janet): document should be set based on whether or not we consider the
+        // tab user-editable, but Qt apps often misuse or don't use documentMode property
+        // so we're currently just always setting it to true for now
 
         //* generic arrow
         void renderArrow( QPainter*, const QRect&, const QColor&, ArrowOrientation ) const;
